==> bonita-commons-9.0.0-sources.jar: org/bonitasoft/engine/monitoring/NoOpExecutorServiceMetricsProvider.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.monitoring;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.ThreadPoolExecutor;

import io.micrometer.core.instrument.MeterRegistry;

/**
 * @author Emmanuel Duchastenier
 */
public class NoOpExecutorServiceMetricsProvider implements ExecutorServiceMetricsProvider {

    @Override
    public ExecutorService bind(MeterRegistry meterRegistry, ThreadPoolExecutor executorService,
            String executorServiceName, long tenantId) {
        return executorService;

    }

    @Override
    public void bindMetricsOnly(MeterRegistry meterRegistry, ThreadPoolExecutor executorService,
            String executorServiceName, long tenantId) {

    }

    @Override
    public void unbind(MeterRegistry meterRegistry, String executorServiceName, long tenantId) {

    }
}

==> bonita-commons-10.3.0-sources.jar: org/bonitasoft/engine/monitoring/NoOpExecutorServiceMetricsProvider.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.monitoring;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.ThreadPoolExecutor;

import io.micrometer.core.instrument.MeterRegistry;

/**
 * @author Emmanuel Duchastenier
 */
public class NoOpExecutorServiceMetricsProvider implements ExecutorServiceMetricsProvider {

    @Override
    public ExecutorService bind(MeterRegistry meterRegistry, ThreadPoolExecutor executorService,
            String executorServiceName) {
        return executorService;
    }

    @Override
    public void bindMetricsOnly(MeterRegistry meterRegistry, ThreadPoolExecutor executorService,
            String executorServiceName) {
    }

    @Override
    public void unbind(MeterRegistry meterRegistry, String executorServiceName) {
    }
}
